gwtb_atom_generator
===============================

Gone with the Blastwave Atom feed generator.

Installation / Usage
--------------------

To install use pip:

    $ pip3 install gwtb_atom_generator


Or clone the repo:

    $ git clone https://github.com/Bystroushaak/gwtb_atom_generator.git
    $ python3 setup.py install
